@@ -1,7 +1,9 @@
+from copy import deepcopy
 from django.conf import settings
 from django.contrib.admin.widgets import AdminSplitDateTime, AdminDateWidget
 from django.forms.models import modelform_factory
 from django.template.loader import render_to_string
+from django.utils import simplejson
 from django.utils.importlib import import_module
 from django.utils.translation import ugettext
 
@@ -108,6 +110,9 @@ class BaseAdaptorField(object):
             return getattr(import_module(path_module), class_adaptor).can_edit(self)
         return self.request.user.is_authenticated and self.request.user.is_superuser
 
+    def loads_to_post(self, request):
+        return simplejson.loads(request.POST.get('value'))
+
     def save(self, value):
         setattr(self.obj, self.field_name, value)
         self.obj.save()
@@ -319,3 +324,36 @@ class AdaptorCommaSeparatedManyToManyField(AdaptorManyToManyField):
     def render_value(self, field_name=None, template_name="inplaceeditform/adaptor_m2m/render_commaseparated_value.html"):
         queryset = super(AdaptorCommaSeparatedManyToManyField, self).render_value(field_name)
         return render_to_string(template_name, {'queryset': queryset})
+
+
+class AdaptorFileField(BaseAdaptorField):
+
+    def loads_to_post(self, request):
+        files = request.FILES.values()
+        return files and files[0] or None
+
+    def treatment_height(self, height):
+        return '25px'
+
+    def render_field(self, template_name="inplaceeditform/adaptor_file/render_field.html"):
+        return super(AdaptorFileField, self).render_field(template_name)
+
+    def render_media_field(self, template_name="inplaceeditform/adaptor_file/render_media_field.html"):
+        return super(AdaptorFileField, self).render_media_field(template_name)
+
+    def render_value(self, field_name=None, template_name='inplaceeditform/adaptor_file/render_value.html'):
+        field_name = field_name or self.field_name_render
+        value = getattr(self.obj, field_name)
+        if not value:
+            return ''
+        config = deepcopy(self.config)
+        context = {'value': value,
+                   'obj': self.obj}
+        config.update(context)
+        return render_to_string(template_name, config)
+
+
+class AdaptorImageField(AdaptorFileField):
+
+    def render_value(self, field_name=None, template_name='inplaceeditform/adaptor_image/render_value.html'):
+        return super(AdaptorImageField, self).render_value(field_name=field_name, template_name=template_name)
